#![allow(non_camel_case_types)]
#![allow(clippy::derive_partial_eq_without_eq)]
#![allow(clippy::upper_case_acronyms)]


#[path = "srv.rs"]
mod srv_idiomatic;
pub mod srv {
    pub use super::srv_idiomatic::*;
    pub mod rmw;
}

